@@ -144,13 +144,14 @@ def app():
                                 puts(colored.yellow(f'Since there are only {gossip_count} gossips made'))
                                 puts(colored.blue(f'Closing point is now set to '
                                                   f'{gossip_count}'))
-                                end_point = gossip_count
-                        end_point = end_point + 1
+                                end_point = gossip_count - 1
+                        end_point = end_point
 
                         value = display_gossips(data['gossips'],
                                         gossips_display_choice, start=start_point, end=end_point)
                         if value == '1':
                             context = gossip_detail(user, data)
+
                             if context.get('gossip'):
                                 if context['value'] == '1':
                                     main_menu(user)
@@ -168,6 +169,7 @@ def app():
                                             comment_on_gossip(context["gossip"]["id"], user)
                                         else:
                                             main_menu(user)
+                                        
                             else:
                                 main_menu(user)
                         else:
@@ -183,14 +185,14 @@ def app():
                                               context['gossip'])
                                 main_menu(user)
                             elif context['value'] == '3':
-                                user_choice = gossip_thread(context['gossip']['id'], user)
-                                if user_choice == '1':
-                                    comment_on_gossip(context["gossip"]["id"], user)
-                                    gossip_thread(context["gossip"]["id"], user)
-                                else:
-                                    main_menu(user)
-                        else:
-                            main_menu(user)
+                                # we set a while True loop so if user choice is 1,
+                                # the comment is added and the user is taken back to the gossip thread
+                                while True:
+                                    user_choice = gossip_thread(context['gossip']['id'], user)
+                                    if user_choice == '1':
+                                        comment_on_gossip(context["gossip"]["id"], user)
+                                    else:
+                                        main_menu(user)
 
             else:
                 puts(colored.yellow("There are no gossips yet"))
@@ -223,6 +225,8 @@ def app():
                 value = display_gossips(gossip_list, user=user)
                 if value == '1':
                     context = gossip_detail(user, data, personal_gossips=True)
+                    print(data['gossips'])
+                    print(gossip_list)
                     if context.get('gossip'):
                         if context['value'] == '1':
                             main_menu(user)
@@ -230,6 +234,7 @@ def app():
                             delete_gossip(data['highest_gossip_id'],
                                           data['gossips'],
                                           context['gossip'])
+                            main_menu(user)
                         elif context['value'] == '3':
                             # we set a while True loop so if user choice is 1,
                             # the comment is added and the user is taken back to the gossip thread
