@@ -43,8 +43,9 @@ def display_gossips(raw_list=None, format_=None, start=0, end=10, user=None):
         raw_list.reverse()
         if user:
             if raw_list:
+                new_list =[x for x in raw_list if x['author'] == user['username']]
                 puts(colored.magenta(f"      ---------These are Your latest posts, {user['username'].capitalize()}---------"))
-                puts(colored.magenta(f"                  ------You Have Made {len(raw_list)} So Far------"))
+                puts(colored.magenta(f"                  ------You Have Made {len(new_list)} So Far------"))
             else:
                 puts(colored.magenta(f"      ---------{user['username'].capitalize()}, You Have No Posts Yet--------"))
                 has_posts = False
@@ -99,8 +100,9 @@ def create_gossip(user):
 
 #on construction
 def gossip_detail(user, data, personal_gossips=False, default_tag=None):
+    detail_gossips_list = data['gossips']
     if personal_gossips:
-        data['gossips'] = [gossip for gossip in data['gossips'] if user['username'] == gossip['author']]
+        detail_gossips_list = [gossip for gossip in detail_gossips_list if user['username'] == gossip['author']]
         puts(colored.yellow(f'please note that, gossipTags of another user\'s gossip is\'nt allowed'))
         puts(colored.yellow(f'To view others users gossips in detail, go to "view latest gossips in the main menu"'))
     if default_tag:
@@ -108,7 +110,7 @@ def gossip_detail(user, data, personal_gossips=False, default_tag=None):
     else:
         gossip_tag = int(input('     Please Input The Target gossip\'s gossipTag: '))
 
-    for gossip in data['gossips']:
+    for gossip in detail_gossips_list:
         if gossip['id'] == gossip_tag:
             with indent(7, quote='|'):
                 wow = 'wow' if len(gossip['wows']) == 0 else 'wows'
@@ -240,7 +242,7 @@ def register():
 
 
 def login(username, password):
-    data = [{}]
+    data = []
     if check_file_existence('register.txt', data):
         with open('register.txt', 'r+') as file:
             if os.path.getsize('register.txt') > 4:
